@import "compass";

// Location Map Widget Search Box
input.location_map_search_box {
    margin-bottom: 10px;
}

// Location Map Widget
.location_map_picker {

    width: 100%;
    height: 350px;
    margin-bottom: 10px;
    background: #EEEEEE;

    @include border-radius(3px);

    img {
        max-width: none !important;
    }

}
